@@ -210,6 +210,10 @@ impl<Conn> DisplayBase for CellDisplay<Conn> {
             .replace(self.request_number.get().wrapping_add(1))
     }
     #[inline]
+    fn has_pending_event(&self) -> bool {
+        !self.inner.borrow().event_queue.is_empty()
+    }
+    #[inline]
     fn push_event(&mut self, event: Event) {
         self.inner.get_mut().event_queue.push_back(event);
     }
@@ -419,6 +423,10 @@ impl<'a, Conn> DisplayBase for &'a CellDisplay<Conn> {
             .replace(self.request_number.get().wrapping_add(1))
     }
     #[inline]
+    fn has_pending_event(&self) -> bool {
+        !self.inner.borrow().event_queue.is_empty()
+    }
+    #[inline]
     fn push_event(&mut self, event: Event) {
         self.inner.borrow_mut().event_queue.push_back(event);
     }
