@@ -184,6 +184,11 @@ impl<Conn> DisplayBase for SyncDisplay<Conn> {
         old
     }
 
+    #[inline]
+    fn has_pending_event(&self) -> bool {
+        !self.event_queue.is_empty()
+    }
+
     #[inline]
     fn push_event(&mut self, event: Event) {
         self.event_queue.push(event).ok();
@@ -409,6 +414,11 @@ impl<'a, Conn> DisplayBase for &'a SyncDisplay<Conn> {
         self.request_number.fetch_add(1, Ordering::SeqCst)
     }
 
+    #[inline]
+    fn has_pending_event(&self) -> bool {
+        !self.event_queue.is_empty()
+    }
+
     #[inline]
     fn push_event(&mut self, event: Event) {
         self.event_queue.push(event).ok();
