@@ -9,22 +9,22 @@ use crate::{
         ChangePointerControlRequest, ChangeWindowAttributesRequest, CloseDown, Colormap,
         ColormapAlloc, CreateColormapRequest, CreateCursorRequest, CreateGcRequest,
         CreateWindowRequest, Cursor, Cw, Drawable, EventMask, FillRule, FillStyle, Font,
-        ForceScreenSaverRequest, Gc, Gcontext, GetKeyboardMappingReply, GetKeyboardMappingRequest,
-        GetModifierMappingReply, GetModifierMappingRequest, GrabServerRequest, Gravity, Gx,
-        InternAtomRequest, JoinStyle, Kb, Keycode, Keysym, LedMode, LineStyle, Pixmap,
-        QueryExtensionRequest, ScreenSaver, SendEventRequest, SetAccessControlRequest,
-        SetCloseDownModeRequest, SubwindowMode, Timestamp, UngrabServerRequest, Visualid, Window,
-        WindowClass,
+        ForceScreenSaverRequest, Gc, Gcontext, GetAtomNameRequest, GetKeyboardMappingReply,
+        GetKeyboardMappingRequest, GetModifierMappingReply, GetModifierMappingRequest,
+        GrabServerRequest, Gravity, Gx, InternAtomRequest, JoinStyle, Kb, Keycode, Keysym, LedMode,
+        LineStyle, Pixmap, QueryExtensionRequest, ScreenSaver, SendEventRequest,
+        SetAccessControlRequest, SetCloseDownModeRequest, SubwindowMode, Timestamp,
+        UngrabServerRequest, Visualid, Window, WindowClass,
     },
     display::{generate_xid, Display, RequestCookie},
     Event, Extension,
 };
-use alloc::{boxed::Box, string::String};
+use alloc::{borrow::Cow, boxed::Box, string::String};
 use cty::c_char;
 
 #[cfg(feature = "async")]
 use crate::{
-    auto::xproto::{InternAtomReply, QueryExtensionReply},
+    auto::xproto::{GetAtomNameReply, InternAtomReply, QueryExtensionReply},
     display::{
         futures::{ExchangeRequestFuture, ExchangeXidFuture, MapFuture, SendRequestFuture},
         AsyncDisplay,
@@ -47,6 +47,7 @@ pub use pixmap::*;
 pub use window::*;
 
 crate::create_paramaterizer! {
+    #[doc = "A set of parameters used to create or change a window."]
     pub struct WindowParameters : (Cw, CreateWindowRequest) {
         background_pixmap (set_back_pixmap,       background_pixmap):     Pixmap,
         background_pixel  (set_back_pixel,        background_pixel):      u32,
@@ -93,6 +94,7 @@ impl WindowParameters {
 }
 
 crate::create_paramaterizer! {
+    #[doc = "A set of parameters used to create or change a graphics context."]
     pub struct GcParameters : (Gc, CreateGcRequest) {
         function              (set_function,              function):              Gx,
         plane_mask            (set_plane_mask,            plane_mask):            u32,
@@ -121,6 +123,7 @@ crate::create_paramaterizer! {
 }
 
 crate::create_paramaterizer! {
+    #[doc = "A set of parameters used to create or change a keyboard control."]
     pub struct KbParameters : (Kb, ChangeKeyboardControlRequest) {
         key_click_percent (set_key_click_percent, key_click_percent): i32,
         bell_percent      (set_bell_percent,      bell_percent):      i32,
@@ -167,34 +170,36 @@ impl GcParameters {
     }
 }
 
+/// A mapping from keycodes to keysyms.
 #[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord)]
 pub struct KeyboardMapping {
     pub keysyms_per_keycode: u8,
     pub keysyms: Box<[Keysym]>,
 }
 
-impl From<GetKeyboardMappingReply> for KeyboardMapping {
+impl<'a> From<GetKeyboardMappingReply<'a>> for KeyboardMapping {
     #[inline]
-    fn from(gkmr: GetKeyboardMappingReply) -> Self {
+    fn from(gkmr: GetKeyboardMappingReply<'a>) -> Self {
         Self {
             keysyms_per_keycode: gkmr.keysyms_per_keycode,
-            keysyms: gkmr.keysyms.into_boxed_slice(),
+            keysyms: gkmr.keysyms.into_owned().into_boxed_slice(),
         }
     }
 }
 
+/// A mapping from keycodes to modifiers.
 #[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord)]
 pub struct ModifierMapping {
     pub keycodes_per_modifier: u8,
     pub keycodes: Box<[Keycode]>,
 }
 
-impl From<GetModifierMappingReply> for ModifierMapping {
+impl<'a> From<GetModifierMappingReply<'a>> for ModifierMapping {
     #[inline]
-    fn from(gmmr: GetModifierMappingReply) -> Self {
+    fn from(gmmr: GetModifierMappingReply<'a>) -> Self {
         Self {
             keycodes_per_modifier: gmmr.keycodes_per_modifier,
-            keycodes: gmmr.keycodes.into_boxed_slice(),
+            keycodes: gmmr.keycodes.into_owned().into_boxed_slice(),
         }
     }
 }
@@ -288,7 +293,7 @@ fn create_gc_request(cid: Gcontext, drawable: Drawable, props: GcParameters) ->
 
 /// Create an `InternAtomRequest` for our use.
 #[inline]
-fn intern_atom_request(name: String, exists: bool) -> InternAtomRequest {
+fn intern_atom_request(name: Cow<'_, str>, exists: bool) -> InternAtomRequest<'_> {
     InternAtomRequest {
         only_if_exists: exists,
         name,
@@ -403,22 +408,25 @@ fn create_colormap_request(
 pub trait DisplayXprotoExt: Display {
     /// Query for extension information.
     #[inline]
-    fn query_extension(
+    fn query_extension<'a, Name: Into<Cow<'a, str>>>(
         &mut self,
-        name: String,
-    ) -> crate::Result<RequestCookie<QueryExtensionRequest>> {
+        name: Name,
+    ) -> crate::Result<RequestCookie<QueryExtensionRequest<'a>>> {
         self.send_request(QueryExtensionRequest {
-            name,
+            name: name.into(),
             ..Default::default()
         })
     }
 
-    /// Query for extension information, but resolve immediately. The `Error::ExtensionNotPresent` error is
+    /// Query for extension information, but resolve immediately. The `ExtensionNotPresent` error is
     /// returned when the extension is not found.
     #[inline]
-    fn query_extension_immediate(&mut self, name: String) -> crate::Result<Extension> {
+    fn query_extension_immediate<'a, Name: Into<Cow<'a, str>>>(
+        &mut self,
+        name: Name,
+    ) -> crate::Result<Extension> {
         let qer = self.exchange_request(QueryExtensionRequest {
-            name,
+            name: name.into(),
             ..Default::default()
         })?;
         Extension::from_reply(qer)
@@ -502,17 +510,22 @@ pub trait DisplayXprotoExt: Display {
 
     /// Intern a string and get a corresponding atom for that string.
     #[inline]
-    fn intern_atom(
+    fn intern_atom<'a, Name: Into<Cow<'a, str>>>(
         &mut self,
-        name: String,
+        name: Name,
         only_if_exists: bool,
-    ) -> crate::Result<RequestCookie<InternAtomRequest>> {
+    ) -> crate::Result<RequestCookie<InternAtomRequest<'a>>> {
+        let name = name.into();
         self.send_request(intern_atom_request(name, only_if_exists))
     }
 
     /// Intern an atom, but try to resolve the request immediately.
     #[inline]
-    fn intern_atom_immediate(&mut self, name: String, only_if_exists: bool) -> crate::Result<Atom> {
+    fn intern_atom_immediate<'a, Name: Into<Cow<'a, str>>>(
+        &mut self,
+        name: Name,
+        only_if_exists: bool,
+    ) -> crate::Result<Atom> {
         let r = self.intern_atom(name, only_if_exists)?;
         Ok(self.resolve_request(r)?.atom)
     }
@@ -524,6 +537,7 @@ pub trait DisplayXprotoExt: Display {
         self.exchange_request(ckcr)
     }
 
+    /// Rings the bell on the keyboard.
     #[inline]
     fn bell(&mut self, percent: i8) -> crate::Result {
         self.exchange_request(BellRequest {
@@ -532,6 +546,7 @@ pub trait DisplayXprotoExt: Display {
         })
     }
 
+    /// Sets the access control for the display.
     #[inline]
     fn set_access_control(&mut self, mode: AccessControl) -> crate::Result {
         self.exchange_request(SetAccessControlRequest {
@@ -540,6 +555,7 @@ pub trait DisplayXprotoExt: Display {
         })
     }
 
+    /// Change the active pointer grab.
     #[inline]
     fn change_active_pointer_grab(
         &mut self,
@@ -550,6 +566,7 @@ pub trait DisplayXprotoExt: Display {
         self.exchange_request(change_active_pointer_grab_request(event_mask, cursor, time))
     }
 
+    /// Set the close down mode.
     #[inline]
     fn set_close_down_mode(&mut self, mode: CloseDown) -> crate::Result {
         self.exchange_request(SetCloseDownModeRequest {
@@ -558,6 +575,7 @@ pub trait DisplayXprotoExt: Display {
         })
     }
 
+    /// Change variables for the pointer.
     #[inline]
     fn change_pointer_control(
         &mut self,
@@ -598,6 +616,7 @@ pub trait DisplayXprotoExt: Display {
         Ok(cid)
     }
 
+    /// Force the screen to go to screensaver.
     #[inline]
     fn force_screensaver(&mut self, mode: ScreenSaver) -> crate::Result {
         self.exchange_request(ForceScreenSaverRequest {
@@ -671,6 +690,25 @@ pub trait DisplayXprotoExt: Display {
     fn ungrab_server(&mut self) -> crate::Result {
         self.exchange_request(UngrabServerRequest::default())
     }
+
+    /// Get the name of an atom.
+    #[inline]
+    fn atom_name(&mut self, atom: Atom) -> crate::Result<RequestCookie<GetAtomNameRequest>> {
+        self.send_request(GetAtomNameRequest {
+            atom,
+            ..Default::default()
+        })
+    }
+
+    /// Get the name of an atom, resolving immedaitely.
+    #[inline]
+    fn atom_name_immediate(&mut self, atom: Atom) -> crate::Result<String> {
+        self.exchange_request(GetAtomNameRequest {
+            atom,
+            ..Default::default()
+        })
+        .map(|ganr| ganr.name.into_owned())
+    }
 }
 
 impl<D: Display + ?Sized> DisplayXprotoExt for D {}
@@ -679,12 +717,12 @@ impl<D: Display + ?Sized> DisplayXprotoExt for D {}
 pub trait AsyncDisplayXprotoExt: AsyncDisplay {
     /// Query for extension information redox.
     #[inline]
-    fn query_extension_async(
-        &mut self,
-        name: String,
-    ) -> SendRequestFuture<'_, Self, QueryExtensionRequest> {
+    fn query_extension_async<'a, 'b, Name: Into<Cow<'b, str>>>(
+        &'a mut self,
+        name: Name,
+    ) -> SendRequestFuture<'a, Self, QueryExtensionRequest<'b>> {
         self.send_request_async(QueryExtensionRequest {
-            name,
+            name: name.into(),
             ..Default::default()
         })
     }
@@ -692,16 +730,16 @@ pub trait AsyncDisplayXprotoExt: AsyncDisplay {
     /// Query for extension information, but resolve immediately redox . The `Error::ExtensionNotPresent`
     /// error is returned when the extension is not found.
     #[inline]
-    fn query_extension_immediate_async(
-        &mut self,
-        name: String,
+    fn query_extension_immediate_async<'a, 'b, Name: Into<Cow<'b, str>>>(
+        &'a mut self,
+        name: Name,
     ) -> MapFuture<
-        ExchangeRequestFuture<'_, Self, QueryExtensionRequest>,
+        ExchangeRequestFuture<'a, Self, QueryExtensionRequest<'b>>,
         fn(crate::Result<QueryExtensionReply>) -> crate::Result<Extension>,
     > {
         MapFuture::run(
             self.exchange_request_async(QueryExtensionRequest {
-                name,
+                name: name.into(),
                 ..Default::default()
             }),
             |repl| repl.and_then(Extension::from_reply),
@@ -808,26 +846,26 @@ pub trait AsyncDisplayXprotoExt: AsyncDisplay {
 
     /// Intern a string and get a corresponding atom for that string redox.
     #[inline]
-    fn intern_atom_async(
-        &mut self,
-        name: String,
+    fn intern_atom_async<'a, 'b, Name: Into<Cow<'b, str>>>(
+        &'a mut self,
+        name: Name,
         only_if_exists: bool,
-    ) -> SendRequestFuture<'_, Self, InternAtomRequest> {
-        self.send_request_async(intern_atom_request(name, only_if_exists))
+    ) -> SendRequestFuture<'a, Self, InternAtomRequest<'b>> {
+        self.send_request_async(intern_atom_request(name.into(), only_if_exists))
     }
 
     /// Intern an atom, but try to resolve the request immediately redox.
     #[inline]
-    fn intern_atom_immediate_async(
-        &mut self,
-        name: String,
+    fn intern_atom_immediate_async<'a, 'b, Name: Into<Cow<'b, str>>>(
+        &'a mut self,
+        name: Name,
         only_if_exists: bool,
     ) -> MapFuture<
-        ExchangeRequestFuture<'_, Self, InternAtomRequest>,
+        ExchangeRequestFuture<'a, Self, InternAtomRequest<'b>>,
         fn(crate::Result<InternAtomReply>) -> crate::Result<Atom>,
     > {
         MapFuture::run(
-            self.exchange_request_async(intern_atom_request(name, only_if_exists)),
+            self.exchange_request_async(intern_atom_request(name.into(), only_if_exists)),
             |repl| repl.map(|repl| repl.atom),
         )
     }
@@ -1046,6 +1084,33 @@ pub trait AsyncDisplayXprotoExt: AsyncDisplay {
     fn ungrab_server_async(&mut self) -> ExchangeRequestFuture<'_, Self, UngrabServerRequest> {
         self.exchange_request_async(UngrabServerRequest::default())
     }
+
+    /// Get the name of an atom, async redox.
+    #[inline]
+    fn atom_name_async(&mut self, atom: Atom) -> SendRequestFuture<'_, Self, GetAtomNameRequest> {
+        self.send_request_async(GetAtomNameRequest {
+            atom,
+            ..Default::default()
+        })
+    }
+
+    /// Get the name of an atom, resolving immediately, async redox
+    #[inline]
+    fn atom_name_immediate_async(
+        &mut self,
+        atom: Atom,
+    ) -> MapFuture<
+        ExchangeRequestFuture<'_, Self, GetAtomNameRequest>,
+        fn(GetAtomNameReply) -> String,
+    > {
+        MapFuture::run(
+            self.exchange_request_async(GetAtomNameRequest {
+                atom,
+                ..Default::default()
+            }),
+            |ganr| ganr.name.into_owned(),
+        )
+    }
 }
 
 #[cfg(feature = "async")]
